@@ -13,12 +13,12 @@ class HE1 (HomomorphicCryptosystem):
             q = prime(HE1.eta(size))
             if p != q:
                 break
-        return HE1(p=p, q=q)
+        return HE1(p, q)
 
-    def __init__ (self, **kwargs):
-        self._p = kwargs['p']
-        self._q = kwargs['q']
-        self._mod = self._p * self._q
+    def __init__ (self, p, q):
+        self._p = p
+        self._q = q
+        self._mod = p * q
 
     def get_modulus (self):
         return self._mod
@@ -30,9 +30,9 @@ class HE1 (HomomorphicCryptosystem):
     def decrypt (self, c):
         return c % self._p
 
-    # Gives the desired size of q in bits given the size of p in bits.
     @staticmethod
     def eta (lam):
+        # Gives the desired size of q in bits given the size of p in bits.
         return lam ** 2 // 32 - lam
 
 class Sum (Computation):
