@@ -13,17 +13,13 @@ class Paillier (HomomorphicCryptosystem):
             q = prime(size)
             if p != q:
                 break
-        return Paillier(p=p, q=q)
+        return Paillier(p, q)
 
-    def __init__ (self, **kwargs):
-        self._p = kwargs['p']
-        self._q = kwargs['q']
-
-        self._N = self._p * self._q
+    def __init__ (self, p, q):
+        self._N = p * q
         self._Nsqr = self._N * self._N
-        self._phi_N = (self._p - 1) * (self._q - 1)
+        self._phi_N = (p - 1) * (q - 1)
         self._g = self._N + 1
-
         self._lambda = self._phi_N
         self._mu = modinv(self._phi_N, self._N)
 
