@@ -29,7 +29,7 @@ def web_server (host, port, db_file):
     web = threading.Thread(target=lambda: httpd.serve_forever())
     try:
         web.start()
-        print('> Voting server listing on ' + host + ':' + str(port))
+        print('> Voting server listening on ' + host + ':' + str(port))
         web.join()
     except KeyboardInterrupt:
         print('> Voting server exiting…')
