@@ -1,3 +1,4 @@
+import argparse
 import random
 from .. import THC
 from ..utils import prime
@@ -10,11 +11,18 @@ from ._computations import Product, PairProduct, RandomPolynomial
 
 if __name__ ==  '__main__':
 
+    ap = argparse.ArgumentParser(description='THC random faults demo.')
+    ap.add_argument('-m', '--mod_size', type=int, default=512,
+                    help='modulus size for cryptosystems')
+    ap.add_argument('-r', '--r_size', type=int, default=32,
+                    help='modular extension parameter size')
+    args = ap.parse_args()
+
     nums = random.sample(range(2**8), 5)
 
     ### RSA
 
-    thc = THC(RSA.new(512), Product(), prime(32))
+    thc = THC(RSA.new(args.mod_size), Product(), prime(args.r_size))
     print('> Multiplications with RSA:')
     print(' * '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
 
@@ -22,7 +30,7 @@ if __name__ ==  '__main__':
 
     ### ElGamal
 
-    thc = THC(ElGamal.new(512), PairProduct(), prime(32))
+    thc = THC(ElGamal.new(args.mod_size), PairProduct(), prime(args.r_size))
     print('> Multiplications with ElGamal:')
     print(' * '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
 
@@ -30,7 +38,7 @@ if __name__ ==  '__main__':
 
     ### Paillier
 
-    thc = THC(Paillier.new(512), Product(), prime(32))
+    thc = THC(Paillier.new(args.mod_size), Product(), prime(args.r_size))
     print('> Additions with Paillier:')
     print(' + '.join([str(n) for n in nums]) + ' =', thc.compute(nums))
 
@@ -39,7 +47,7 @@ if __name__ ==  '__main__':
     ### HE1
 
     rp = RandomPolynomial(5, 2**8)
-    thc = THC(HE1.new(256), rp, prime(32))
+    thc = THC(HE1.new(args.mod_size // 2), rp, prime(args.r_size))
     print('> Polynomial with HE1:')
     print('random polynomial P(x) =', rp)
     for n in nums:
