@@ -1,4 +1,4 @@
-from abc import *
+from abc import ABC, abstractmethod
 
 ###
 ### Interfaces
@@ -7,7 +7,7 @@ from abc import *
 class HomomorphicCryptosystem (ABC):
 
     @abstractmethod
-    def __init__ (self, **kwargs):
+    def __init__ (self):
         pass
 
     @abstractmethod
@@ -22,6 +22,10 @@ class HomomorphicCryptosystem (ABC):
     def decrypt (self, c):
         pass
 
+    def mod (self, c, mod):
+        # returns c % mod for a ciphertext c
+        return c % mod
+
 class Computation (ABC):
 
     @abstractmethod
